<?php

namespace Superrobota\Bankoffer\Policies;

use Litepie\User\Contracts\UserPolicy;
use Superrobota\Bankoffer\Models\Bankoffer;

class BankofferPolicy
{

    /**
     * Determine if the given user can view the bankoffer.
     *
     * @param UserPolicy $user
     * @param Bankoffer $bankoffer
     *
     * @return bool
     */
    public function view(UserPolicy $user, Bankoffer $bankoffer)
    {
        if ($user->canDo('bankoffer.bankoffer.view') && $user->isAdmin()) {
            return true;
        }

        return $bankoffer->user_id == user_id() && $bankoffer->user_type == user_type();
    }

    /**
     * Determine if the given user can create a bankoffer.
     *
     * @param UserPolicy $user
     * @param Bankoffer $bankoffer
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('bankoffer.bankoffer.create');
    }

    /**
     * Determine if the given user can update the given bankoffer.
     *
     * @param UserPolicy $user
     * @param Bankoffer $bankoffer
     *
     * @return bool
     */
    public function update(UserPolicy $user, Bankoffer $bankoffer)
    {
        if ($user->canDo('bankoffer.bankoffer.edit') && $user->isAdmin()) {
            return true;
        }

        return $bankoffer->user_id == user_id() && $bankoffer->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given bankoffer.
     *
     * @param UserPolicy $user
     * @param Bankoffer $bankoffer
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Bankoffer $bankoffer)
    {
        return $bankoffer->user_id == user_id() && $bankoffer->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given bankoffer.
     *
     * @param UserPolicy $user
     * @param Bankoffer $bankoffer
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Bankoffer $bankoffer)
    {
        if ($user->canDo('bankoffer.bankoffer.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given bankoffer.
     *
     * @param UserPolicy $user
     * @param Bankoffer $bankoffer
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Bankoffer $bankoffer)
    {
        if ($user->canDo('bankoffer.bankoffer.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
